<?php
/**
 * @package ARGPD
 * @subpackage Ui
 * @since 0.0.0
 *
 * @author César Maeso <superadmin@superadmin.es>
 *
 * @copyright (c) 2018, César Maeso (https://superadmin.es)
 */

/**
 * Ui class.
 *
 * @since  0.0.0
 */
class ARGPD_Ui {

	/**
	 * Parent plugin class.
	 *
	 * @var    string
	 * @since  0.0.0
	 */
	protected $plugin = null;


	/**
	 * Constructor.
	 *
	 * @since  0.0.0
	 *
	 * @param  Main plugin object.
	 */
	public function __construct( $plugin ) {
		
		// set parent plugin
		$this->plugin = $plugin;
		
		// initiate our hooks
		$this->hooks();
	}

	/**
	 * Initiate our hooks.
	 *
	 * @since  0.0.0
	 */
	public function hooks() {
		
		// config tab
		add_action('argpd_settings_tab', array($this, 'argpd_ajustes_tab'), 1);		
		add_action('argpd_settings_content', array($this, 'argpd_ajustes_content'));

		
		// pages tab
		add_action('argpd_settings_tab', array($this, 'argpd_paginas_tab'), 1);
		add_action('argpd_settings_content', array($this, 'argpd_paginas_content'));
	
		// ayuda
		add_action('argpd_settings_tab', array($this, 'argpd_ayuda_tab'), 1);
		add_action('argpd_settings_content', array($this, 'argpd_ayuda_content'));

		// ajax scripts
		add_action( 'admin_footer', array($this, 'argpd_change_country' )); 
		add_action( 'wp_ajax_argpd_get_states', array($this, 'argpd_get_states' )); 
	}





	function argpd_change_country() { ?>

		<script type="text/javascript" >			
			
			var ajaxurl = '<?php echo admin_url("admin-ajax.php"); ?>';

			jQuery(document).ready(function($) {
				
    			$('body').on('change', '.countries', function() {    				
      				var countryid = $(this).val();
      				if(countryid != '') {
        				var data = {
          					action: 'argpd_get_states',
          					country: countryid,
          					'security': '<?php echo wp_create_nonce("load_states"); ?>'
        				}
        				
        				$('.load-state').html("<span><?php _e('cargando...','argpd');?></span>");
        				$.post(ajaxurl, data, function(response) {
          					$('.load-state').html(response);
        				});
      				}
    			});
    		});
		</script> 
	<?php }

	

	function argpd_get_states(){
		check_ajax_referer('load_states', 'security');
  		$country = $_POST['country'];
  		
  		$settings= $this->plugin->argpd_settings;			
  		$states= $settings->get_states($country);  		
  		?> 
			<select name="provincia-code" id="provincia-code">
				<option value="" selected="selected">Selecciona</option>
				<?php	
				foreach ($states as $i) {
					printf("<option value=\"%s\" %s>%s</option>", 
						$i['code'],
						($i['code'] == $settings->get_setting('provincia-code'))?("selected=\"selected\""):"",
						$i['name']);
				}								
				?>
			</select>

    	<?php
		wp_die();
	}



	/**
	 * Echo 'Titular' tab of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_ajustes_tab(){
		global $argpd_active_tab; 
		?>
		<a 	class="nav-tab <?php echo $argpd_active_tab == 'ajustes' || '' ? 'nav-tab-active' : ''; ?>" 
			href="<?php echo admin_url( 'admin.php?page=argpd&tab=ajustes' ); ?>">
			<?php _e( 'Titular', 'argpd' ); ?> 
		</a>
		<?php
	}


	/**
	 * Echo 'Titular' content of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_ajustes_content(){
		global $argpd_active_tab;
		if ( '' || 'ajustes' != $argpd_active_tab )
			return;

		$settings= $this->plugin->argpd_settings;
		?>
		
		
		<form method="post" action="admin-post.php" style="padding-top: 20px">
			<?php wp_nonce_field( 'argpd' ); ?>
			<input type="hidden" value="argpd_setup" name="action"/>
			
			<div>
				<h2 class="title"><?php _e( 'Sobre el Titular', 'argpd' ); ?></h2>
				<p>
					Aquí añades información sobre el titular (Persona física o empresa) y sobre la Web.
				</p>

				<p>
					Pulsa <b>Guardar cambios</b> para actualizar el contenido de las páginas de <i>Aviso Legal</i>, <i>Política de Privacidad</i> y <i>Política de Cookies</i>.
				</p>
			</div>

							
			<table class="form-table">
				<tbody>

					<?php /* Titular */ ?>
					<tr>
						<th scope="row">
							<label for="titular"><?php _e('Nombre del Titular', 'argpd');?></label>
						</th>
						<td>

							<input 	type="text" 
									name="titular" 
									value="<?php echo $settings->get_setting('titular'); ?>" 
									/>
							<p class="description">
								Nombre del titular o denominación social si es una empresa
							</p>				
						</td>
					</tr>
					
					<?php /* Identificador fiscal */?>
					<tr>
						<th scope="row">
							<label for="id-fiscal"><?php _e('Identificador Fiscal', 'argpd');?></label>
						</th>
						<td>

							<input 	type="text" 
									name="id-fiscal" 
									value="<?php echo $settings->get_setting('id-fiscal'); ?>" 
									/>
							<p class="description">
								NIF o CIF del titular
							</p>				
						</td>
					</tr>

					<?php /* Domicilio */?>
					<tr>
						<th scope="row">
							<label for="domicilio"><?php _e('Domicilio', 'argpd');?></label>
						</th>
						<td>

							<input 	type="text" 
									name="domicilio" 
									value="<?php echo $settings->get_setting('domicilio'); ?>" 
									/>
							<p>								
							
							<span class="load-state">
							<select name="provincia-code" id="provincia-code">
								<option value="" selected="selected">Selecciona</option>
								<?php		
								//$provincias= $settings->get_states();
								$country= $settings->get_setting('pais');
								$states= $settings->get_states($country);
								foreach ($states as $i) {
									printf("<option value=\"%s\" %s>%s</option>", 
										$i['code'],
										($i['code'] == $settings->get_setting('provincia-code'))?("selected=\"selected\""):"",
										$i['name']);
								}								
								?>
							</select>

							</span>

							<select name="pais" id="pais" class="countries">
								<?php
									$countries= $settings->get_countries();
									foreach ($countries as $key => $value) {
										printf("<option value=\"%s\" %s>%s</option>", 
											$key, 
											($key == $settings->get_setting('pais'))?("selected=\"selected\""):"",
											$value);
									}								
								?>
							</select>
							</p>

							<p class="description">
								Domicilio del titular o Domicilio Fiscal
							</p>				
						</td>
					</tr>						
					
					
					<?php /* correo electrónico */?>
					<tr>
						<th scope="row">
							<label for="correo"><?php _e('Correo electrónico', 'argpd');?></label>
						</th>
						<td>

							<input 	type="text" 
									name="correo" 
									value="<?php echo $settings->get_setting('correo'); ?>" 
									/>
							<p class="description">
								Es la dirección de correo para contactar y dónde los usuarios van a poder ejercer sus derechos. 
							</p>				
						</td>
					</tr>
				</tbody>
			</table>
			<?php submit_button(); ?>

			<?php /* Sobre el sitio web */ ?>
			<div>
				<h2 class="title"><?php _e( 'Sobre el sitio Web', 'argpd' ); ?></h2>
				<p>
					En este apartado configurás datos de tu sitio web.
				</p>
			</div>
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row">
							<?php _e('URL del sitio', 'argpd');?>
						</th>
						<td>
							<?php echo $settings->get_setting('dominio'); ?>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="finalidad"><?php _e('Finalidad', 'argpd');?></label>
						</th>
						<td>
							<textarea 
								name="finalidad" 
								id="finalidad" 
								cols="40"
								rows="3"
								><?php echo $settings->get_setting('finalidad'); ?></textarea>
							<p class="description">
								Añade una descripción de la finalidad de este sitio web. 
							</p>
							<p class="description">
								Por ejemplo: Informar sobre Tecnología o vender zapatos.
							</p>
							<br/>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<label for="hosting-info"><?php _e('Alojamiento', 'argpd');?></label>
						</th>
						<td>

							<input 	type="text" 
									name="hosting-info" 
									value="<?php echo $settings->get_setting('hosting-info'); ?>" 
									/>
							<p class="description">
								Indica tu proveedor de alojamiento o hosting y un enlace a su política de privacidad.
							</p>				
						</td>
					</tr>					
					<tr>
						<th scope="row">
							<label for="pais"><?php _e('Servicios de Terceros', 'argpd');?></label>
						</th>
						<td>
							<label  for="thirdparty-dclick">
							<input 	name="thirdparty-dclick" 
									type="checkbox" 
									id="thirdparty-dclick" 
									value="1"
									<?php ($settings->get_setting('thirdparty-dclick') == 1) && printf("checked"); ?>
									>
									<?php _e('DoubleClick', 'argpd'); ?>
							</label>
							<p class="description">
								Marcar si el sitio usa DoubleClick.
							</p>
							<br/>
							<label for="thirdparty-ganalytics">
							<input 	name="thirdparty-ganalytics" 
									type="checkbox" 
									id="thirdparty-ganalytics" 
									value="1"
									<?php ($settings->get_setting('thirdparty-ganalytics') == 1) && printf("checked"); ?>
									>
									<?php _e('Google Analytics', 'argpd'); ?>
							</label>
							<p class="description">
								Marcar si el sitio utiliza Google Analytics
								<?php echo $settings->get_setting('thirdparty-ganalytics'); ?>
							</p>
							<br/>

							<?php /* thidparte social */ ?>
							<label for="thirdparty-social">
							<input 	name="thirdparty-social" 
									type="checkbox" 
									id="thirdparty-social" 
									value="1" 
									<?php ($settings->get_setting('thirdparty-social') == 1) && printf("checked"); ?>
									>
									<?php _e('Redes Sociales', 'argpd');?>
							</label>
							<p class="description">
								Marcar si el sitio utiliza redes sociales para publicar, likes, comentarios,...
							</p>
							<br/>

							<?php /* thirdparty mailchimp */ ?>
							<label for="thirdparty-mailchimp">
							<input 	name="thirdparty-mailchimp" 
									type="checkbox" 
									id="thirdparty-mailchimp" 
									value="1" 
									<?php ($settings->get_setting('thirdparty-mailchimp') == 1) && printf("checked"); ?>
									>
									<?php _e('Mailchimp', 'argpd');?>
							</label>
							<p class="description">
								Marcar si el sitio utiliza Mailchimp.
							</p>
							<br/>

						</td>
					</tr>
				</tbody>
			</table>
			<?php submit_button(); ?>

			<?php /* Más ajustes */?>
			<div>
				<h2 class="title"><?php _e( 'Más Ajustes', 'argpd' ); ?></h2>
				<p>
					Algunos ajustes más del sitio.
				</p>
			</div>
			<table class="form-table">
				<tbody>	
					<tr>
						<th scope="row">
							<label for="pais"><?php _e('Cláusulas', 'argpd');?></label>
						</th>
						<td>
							<label for="clause-exclusion">
							<input 	name="clause-exclusion" 
									type="checkbox" 
									id="clause-exclusion" 
									value="1"
									<?php ($settings->get_setting('clause-exclusion') == 1) && printf("checked"); ?>
									>
									<?php _e('Cláusula de exclusión', 'argpd'); ?>
							</label>
							<p class="description">
								Añadir una cláusula para reservar el Derecho de exclusión.
							</p>					
							<br/>
							<label for="clause-terceros">
							<input 	name="clause-terceros" 
									type="checkbox" 
									id="clause-terceros" 
									value="1" 
									<?php ($settings->get_setting('clause-terceros') == 1) && printf("checked"); ?>
									>
									<?php _e('Cesión de datos a terceros', 'argpd'); ?>
							</label>
							<p class="description">
								Añádir una cláusula para permitir la cesión a terceros.
							</p>
							<br/>
							
							<?php /* clausula mayoría edad */ ?>
							<label for="clause-edad">
							<input 	name="clause-edad" 
									type="checkbox" 
									id="clause-edad" 
									value="1" 
									<?php ($settings->get_setting('clause-edad') == 1) && printf("checked"); ?>
									>
									<?php _e('Requisito mayoría edad', 'argpd');?>
							</label>
							<p class="description">
								Añádir una cláusula para requerir una edad mínima.
							</p>
							<p class="description">
								Marca esta opción si página web esta destianada sólo a mayores de edad.
							</p>							
							<br/>

							<?php /* clausula protected data */ ?>
							<label for="clause-protegidos">
							<input 	name="clause-protegidos" 
									type="checkbox" 
									id="clause-protegidos" 
									value="1" 
									<?php ($settings->get_setting('clause-protegidos') == 1) && printf("checked"); ?>
									>
									<?php _e('Datos especialmente protegidos', 'argpd');?>
							</label>
							<p class="description">
								Marcar si se recogen datos especialmento protegidos (médicos, religión, orientación sexual,...)
							</p>
							<br/>

							<?php /* clausula portabilidad  */ ?>
							<label for="clause-portabilidad">
							<input 	name="clause-portabilidad" 
									type="checkbox" 
									id="clause-portabilidad" 
									value="1" 
									<?php ($settings->get_setting('clause-portabilidad') == 1) && printf("checked"); ?>
									>
									<?php _e('Portabilidad de datos', 'argpd');?>
							</label>
							<p class="description">
								Marcar para permitir la portabilidad de datos.
							</p>
							<br/>
						</td>
					</tr>
				</tbody>
			</table>


			<?php submit_button(); ?>
		</form>
		<?php					
	}


	/**
	 * Echo 'Integracion' tab of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_paginas_tab(){
		global $argpd_active_tab; 
		?>
		<a 	class="nav-tab <?php echo $argpd_active_tab == 'paginas' || '' ? 'nav-tab-active' : ''; ?>" 
			href="<?php echo admin_url( 'admin.php?page=argpd&tab=paginas' ); ?>">
			<?php _e( 'Integración', 'argpd' ); ?> 
		</a>
		<?php
	}	


	/**
	 * Echo 'Integracion' content of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_paginas_content(){
		global $argpd_active_tab;
		if ( 'paginas' != $argpd_active_tab )
			return;

		$settings= $this->plugin->argpd_settings;
		?>
 
		<div>
			<h2 class="title"><?php _e( 'Páginas Legales', 'argpd' ); ?></h2>
			<p>
				El plugin ya ha creado las páginas legales al activarse. 
			</p>
			<p>
				Desde este apartado puedes activar, desactivar o cambiar
				la página dónde quieres que aparezca cada texto legal.
			</p>
			<p>
				Para desactivar un texto legal selecciona "Ninguna" en la columna <i>Página</i> y guarda los cambios. 
			</p>
		</div>

		<form method="post" action="admin-post.php" style="padding-top: 20px">
			<div>

				<?php wp_nonce_field( 'argpd' ); ?>
				<input type="hidden" value="argpd_pages_setup" name="action"/>
	
				<table class="wp-list-table widefat fixed striped posts">
					<thead>
						<tr>
							<td>Texto Legal</td>
							<td>Página</td>
							<td>Código Abreviado</td>
							<td>Ayuda</td>
						</tr>
					</thead>
					<tbody>

						<?php /* Aviso Legal */?>
						<tr>
							<th scope="row">
								<label for="avisolegal"><?php _e('Aviso Legal', 'argpd');?></label>
								<?php if ($settings->get_setting('avisolegalID') != 0) { ?>
								<div class="row-actions">
									<span class="view">
										<?php
										printf("<a href=\"%s?page_id=%s\">%s</a>",
											get_site_url(),
											$settings->get_setting('avisolegalID'),
											"Ver"
											);							
										?>
									</span>
								</div>
								<?php } ?> 
							</th>
							<td>
								<select name="avisolegal" id="avisolegal">
									<option value="0"
											<?php if ($settings->get_setting('avisolegalID') == 0) printf("selected=\"selected\"");?>
											>
											Ninguna</option>
									<?php								
									foreach (get_pages() as $page) {
										printf("<option value=\"%s\" %s>%s</option>", 
											$page->ID, 
											($page->ID == $settings->get_setting('avisolegalID'))?("selected=\"selected\""):"",
											$page->post_title);
									}								
									?>
								</select>
								
								<p class="description">
								<?php 
									if ($settings->get_setting('avisolegalID') == 0)
									echo "Selecciona una página para activar";
								?>
								</p>
							</td>
							<td>
								<span class="shortcode">[argpd_aviso-legal]</span>
							</td>
							<td></td>
						</tr>

						<?php /* Política de privacidad */?>
						<tr>
							<th scope="row">
								<label for="privacidad"><?php _e('Política de Privacidad', 'argpd');?></label>
								<?php if ($settings->get_setting('privacidadID') != 0) { ?>
								<div class="row-actions">
									<span class="view">
										<?php
										printf("<a href=\"%s?page_id=%s\">%s</a>",
											get_site_url(),
											$settings->get_setting('privacidadID'),
											"Ver"
											);							
										?>
									</span>				
								</div>
								<?php } ?> 
							</th>
							<td>
								<select name="privacidad" id="privacidad">
									<option value="0"
											<?php if ($settings->get_setting('privacidadID') == 0) printf("selected=\"selected\"");?>
											>
											Ninguna</option>
									<?php								
									foreach (get_pages() as $page) {
										printf("<option value=\"%s\" %s>%s</option>", 
											$page->ID, 
											($page->ID == $settings->get_setting('privacidadID'))?("selected=\"selected\""):"",
											$page->post_title);
									}								
									?>
								</select>
								<p class="description">
								<?php 
									if ($settings->get_setting('privacidadID') == 0)
									echo "Selecciona una página para activar";
								?>
								</p>

							</td>
							<td>
								<span class="shortcode">[argpd_politica-privacidad]</span>
							</td>
							<td>
								<a 	href="https://superadmin.es/blog/wordpress/crear-politica-de-privacidad/" 
									class="button" 
									target="_blank"
									style="background-color: #03A9F4;color: white;border-color: #03A9F4;"
								>La política de privacidad</a>
							</td>
						</tr>

						<?php /* Política de cookies */?>
						<tr>
							<th scope="row">
								<label for="cookies"><?php _e('Política de Cookies', 'argpd');?></label>
								<?php if ($settings->get_setting('cookiesID') != 0) { ?>
								<div class="row-actions">
									<span class="view">
										<?php
										printf("<a href=\"%s?page_id=%s\">%s</a>",
											get_site_url(),
											$settings->get_setting('cookiesID'),
											"Ver"
											);							
										?>
									</span>
								</div>
								<?php } ?> 
							</th>
							<td>
								<select name="cookies" id="cookies">
									<option value="0"
											<?php if ($settings->get_setting('cookiesID') == 0) printf("selected=\"selected\"");?>
											>
											Ninguna</option>
									<?php								
									foreach (get_pages() as $page) {
										printf("<option value=\"%s\" %s>%s</option>", 
											$page->ID, 
											($page->ID == $settings->get_setting('cookiesID'))?("selected=\"selected\""):"",
											$page->post_title);
									}								
									?>
								</select>
								<p class="description">
								<?php 
									if ($settings->get_setting('cookiesID') == 0)
									echo "Selecciona una página para activar";
								?>
								</p>
							</td>
							<td>
								<span class="shortcode">[argpd_politica-cookies]</span>
							</td>
							<td></td>
						</tr>												
						<?php /* Información Básica */?>
						<tr>
							<th scope="row">
								<label><?php _e('Deber de Informar', 'argpd');?></label>								
								<div class="row-actions">
								</div>
							</th>
							<td>								
							</td>							
							<td>
								<span class="shortcode">[argpd_deber_de_informar]</span>
							</td>
							<td>
								<a 	href="https://superadmin.es/blog/emprendedor/cumplir-deber-de-informar-rgpd/" 
									class="button" 
									target="_blank"
									style="background-color: #03A9F4;color: white;border-color: #03A9F4;"
								>Cumplir el deber de informar</a>
							</td>
						</tr>																		
					</tbody>
				</table>
				<?php submit_button(); ?>				
			</div>

			<br><br>
			<div>
				<h2 class="title"><?php _e( 'Consentimiento y Deber de Informar', 'argpd' ); ?></h2>
				<p>					
					<a href="https://superadmin.es/blog/emprendedor/cumplir-deber-de-informar-rgpd/" 
							 target="_blank"
							 >
							<span style="text-decoration: none" class="dashicons dashicons-editor-help"></span>
							Guía para cumplir el deber de informar
					</a>
				</p>
				<p>
					Este apartado te sirve para dar cumplimiento al deber de informar en los formularios web.
				</p>
			</div>
			
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row">
							<label><?php _e('Activar en', 'argpd');?></label>
						</th>
						<td>
							<label  for="option-comments">
								<input 	name="option-comments" 
									type="checkbox" 
									id="option-comments" 
									value="1"							
									<?php ($settings->get_setting('option-comments') == 1) && printf("checked"); ?>
									>
									<?php _e('Comentarios ', 'argpd'); ?>
							</label>
							<p class="description">
								Marca para añadir una casilla de verificación, obtener el consentimiento y satisfacer el deber de informar.
							</p>													
							<br/>

							<label  for="option-forms">
								<input 	name="option-forms" 
										type="checkbox" 
										id="option-forms" 
										value="1"							
										<?php ($settings->get_setting('option-forms') == 1) && printf("checked"); ?>
										>
										<?php _e('Formularios', 'argpd'); ?>
							</label>
							<p class="description">
								Marca si en el sitio web hay formularios. <br>
								Utiliza el shortcode [argpd_deber_de_informar] debajo de tu formulario para mostrar el deber de informar.
							</p>
							<br/>

							<label  for="option-footer">
								<input 	name="option-footer" 
										type="checkbox" 
										id="option-footer" 
										value="1"							
										<?php ($settings->get_setting('option-footer') == 1) && printf("checked"); ?>
										>
										<?php _e('Pie de página', 'argpd'); ?>
							</label>
							<p class="description">
								Marca para crear enlaces a las páginas legales en el pie de página.<br>
							</p>
						</td>
					</tr>
					
					<?php /* Diseño */?>
					<tr>
						<th scope="row">
							<label for="consentimiento-label"><?php _e('Texto para<br>el consentimiento', 'argpd');?></label>
						</th>
						<td>
								<textarea 
									name="consentimiento-label" 
									id="consentimiento-label" 
									cols="60"
									rows="3"
									placeholder="He leído y acepto la política de privacidad."
									><?php echo $settings->get_setting('consentimiento-label'); ?></textarea>						
									<br><span class="description">
									Deja en blanco para mostrar el texto por defecto.</span>
						</td>
					</tr>					
				</tbody>
			</table>
			<?php submit_button(); ?>


			<br><br>
			<div>
				<h2 class="title"><?php _e( 'Ley de Cookies', 'argpd' ); ?></h2>				
				<p>
					Este apartado te sirve para dar cumplimiento a la ley de Cookies.
				</p>
				<div>					
					
						<table class="form-table">
							<tbody>	
								<?php /* Activar/Desactivar cookies */?>
								<tr>
									<th scope="row">
										<label for="option-cookies"><?php _e('Activar', 'argpd');?></label>
									</th>
									<td>
										<label  for="option-cookies">
										<input 	name="option-cookies" 
												type="checkbox" 
												id="option-cookies" 
												value="1"							
												<?php ($settings->get_setting('option-cookies') == 1) && printf("checked"); ?>
												>
												<?php _e('Banner de Política de cookies ', 'argpd'); ?>
										</label>
										<p class="description">
											Marca para activar el banner de cookies en todas las páginas.
										</p>
									</td>
								</tr>								
								<?php /* Texto */?>
								<tr>
									<th scope="row">
										<label for="cookies-label"><?php _e('Texto personalizado <br>en el banner', 'argpd');?></label>
									</th>
									<td>								

										<textarea 
											name="cookies-label" 
											id="cookies-label" 
											cols="60"
											rows="3"
											placeholder="Esta web utiliza cookies. Puedes ver aquí la política de cookies. Si continuas navegando estás aceptándola."
											><?php echo $settings->get_setting('cookies-label'); ?></textarea>						
											<br>
											<span class="description">
												Deja en blanco para mostrar el texto por defecto.
											</span>
									</td>
								</tr>
							</tbody>
						</table>
					
				</div>
			</div>			
			<?php submit_button(); ?>

			<br><br>
			<div>
				<h2 class="title"><?php _e( 'Estilo y diseño', 'argpd' ); ?></h2>				
				<div>					
					
						<table class="form-table">
							<tbody>	
								<?php /* Theme */?>
								<tr>
									<th scope="row">
										<label for="cookies-theme"><?php _e('Tema', 'argpd');?></label>
									</th>
									<td>

									<select name="cookies-theme" id="cookies-theme">
										<?php
											$cookie_themes= $settings->get_cookie_themes();
											foreach ($cookie_themes as $key => $value) {
												printf("<option value=\"%s\" %s>%s</option>", 
													$key, 
													($key == $settings->get_setting('cookies-theme'))?("selected=\"selected\""):"",
													$value);
											}								
											?>
									</select>
									
									<a 	href="https://superadmin.es/adapta-rgpd/personalizar-banner-cookies/" 
							 			target="_blank"
							 			>
										<span style="text-decoration: none" class="dashicons dashicons-editor-help"></span>
											Cómo personalizar con CSS
									</a>

									</td>
								</tr>	

								<?php /* list style */?>
								<tr>
									<th scope="row">
										<label><?php _e('Listas', 'argpd');?></label>
									</th>
									<td>
										<select name="informbox-theme" id="informbox-theme">
										<?php							
											$informbox_themes= $settings->get_informbox_themes();
											foreach ($informbox_themes as $key => $value) {
												printf("<option value=\"%s\" %s>%s</option>", 
													$key, 
													($key == $settings->get_setting('informbox-theme'))?("selected=\"selected\""):"",
													$value);
											}								
											?>
										</select>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>
				<?php submit_button(); ?>
		</form>
		
		<?php
	}

	
	/**
	 * Echo 'Ayuda' tab of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_ayuda_tab(){
		global $argpd_active_tab; 
		?>
		<a 	class="nav-tab <?php echo $argpd_active_tab == 'ayuda' || '' ? 'nav-tab-active' : ''; ?>" 
			href="<?php echo admin_url( 'admin.php?page=argpd&tab=ayuda' ); ?>">
			<?php _e( 'Ayuda', 'argpd' ); ?> 
		</a>
		<?php
	}	


	/**
	 * Echo 'Ayuda' content of plugin settings
	 *
	 * @since  0.0.0
	 */
	public function argpd_ayuda_content(){
		global $argpd_active_tab;
		if ( 'ayuda' != $argpd_active_tab )
			return;
		?>
 
			<div>
				<h2 class="title"><?php _e( 'Ayuda', 'argpd' ); ?></h2>
    			
    			<?php     				
    				echo $this->plugin->pages->ayuda_view();

    				echo $this->plugin->pages->disclaimer();
    			?>

			</div>		
		<?php
	}	


	/**
	 * Echo plugin settings view
	 *
	 * @since  0.0.0
	 */ 
	public function options_ui(){

		global $argpd_active_tab;
		$argpd_active_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : 'ajustes'; 		
		?>
		
		<?php /* ARGPD messages */ ?>
		<?php 
			
			$message= _('Algo fue mal.', 'argpd');

			if ( isset($_GET['message']) ){
				switch ($_GET['message']){ 
					case "saved": 
						$message= _('Los cambios se han guardado.', 'argpd');
						break;
					default:
						$message= _('La página ya existe.', 'argpd');
						break;
				}
				?>
				<div id="message" 
					 class="notice notice-success is-dismissible"
					 >
					 <p><?php echo $message ?></p>
					 <button type="button" 
					 	     class="notice-dismiss"
					 	     >
					 	     <span class="screen-reader-text">
					 	     	Descartar este aviso.
					 	     </span>
					</button>
				</div>
		<?php } ?>
		
		
		<div class="wrap">		
			<h1>Adaptación RGPD</h1>

			<?php 
				$settings= $this->plugin->argpd_settings;
				if ($settings->get_setting('renuncia') == 0) { ?>
				<div>
    				<div>
    					<?php 
    						echo $this->plugin->pages->disclaimer();
    					?>

						<form method="post" action="admin-post.php">
							<?php wp_nonce_field( 'argpd' ); ?>
							<input type="hidden" value="argpd_disclaimer" name="action"/>

							<p class="submit">
								<input 	type="submit" 
										name="submit" 
										id="submit" 
										class="button button-primary" 
										value="Aceptar">
							</p>
						</form>
					</div>
				</div>
				

			<?php } else { ?>

			<div>
				<h2 class="nav-tab-wrapper">
					<?php
					// echo tabs by tab param
					do_action('argpd_settings_tab');
					?>
				</h2>
		
				<?php
					// echo content by tab param
					do_action('argpd_settings_content');
				?>
			</div>
			<?php } ?>
			<hr>
			<p>
				<em>Adapta RGPD creado por <a href="https://superadmin.es">SuperAdmin</a>.</em>
			</p>
		</div>
		<?php
	}
}


